@@ -4,7 +4,7 @@ from fastapi.middleware.cors import CORSMiddleware
 from apiautomata.routes import home, proxy
 from apiautomata.routes.exchange import instrument_exchange, exchange_rate
 from apiautomata.routes.missing import missing
-from apiautomata.routes.process import process_enablement, process_status
+from apiautomata.routes.process import process_enablement, process_status, process_invoke
 from apiautomata.routes.transform import exchange_transform, trade_transform
 
 app = FastAPI()
@@ -18,6 +18,7 @@ app.include_router(trade_transform.router)
 app.include_router(exchange_rate.router)
 app.include_router(process_enablement.router)
 app.include_router(process_status.router)
+app.include_router(process_invoke.router)
 
 origins = ['*']
 
